<script setup>
import facilityApi from "@/api/facility/index";
import pointApi from "@/api/facility/point";
import supplierApi from "@/api/facility/supplier.js";
import facilityTypeApi from "@/api/facility/facilityType.js";
import commonParameters from "@/api/configuration/commonParameters/index.js";
import waterFacilityParameter from "@/api/facility/parameter.js";
import {PREURL} from '@/config/index'
import setPostParams from "@/utils/searchParams.js";
const route = useRoute();
const preUrl = ref(PREURL);
const {proxy} = getCurrentInstance();

/**
 * 搜索相关
 */
/** 搜索按钮操作 */
function handleQuery() {
    getList({keywords: searchParams.value.facilityCode})
}

/** 重置按钮操作 */
function resetQuery() {
    proxy.resetForm("queryRef");
    handleQuery();
}

/**
 *  Table表格权限数据列表相关
 */
const pageParam = ref({
    total: 0,
    limit: 0,
    page: 1,
})
const tableData = ref([]);
const inpTip = '请输入', selTip = '请选择';
let tableHeader = ref({
    facilityCode: '设备编号',
    facilityName: '设备名称',
    facilityTypeName: '设备类型',
    pointName: '设备监控点',
    facilityUrl: '设备图片',
    installDate:'安装日期',
})

/** 获取权限列表 */
async function getList(val) {
    let postParam = setPostParams(val)
    await facilityApi().search(postParam).then((res) => {
        tableData.value = res.data.list
        pageParam.value.total = res.data.total
        pageParam.value.limit = res.data.limit
        pageParam.value.page = res.data.page
    })
}

/**
 *  表单相关
 */
const formLabel = ({
    facilityCode: '设备编号',
    facilityName: '设备名称',
    facilityType: '设备类型',
    pointId: '设备监控点',
    facilityUrl: '设备图片',
    remark:'备注信息',
    createTimeView: '创建时间'
})
const rules = ref({
    facilityCode: [{required: true, message: `${inpTip + formLabel.facilityCode}`, trigger: "blur"}],
    facilityName: [{required: true, message: `${inpTip + formLabel.facilityName}`, trigger: "blur"}],
    facilityType: [{required: true, message: `${inpTip + formLabel.facilityTypeName}`, trigger: "blur"}],
    pointId: [{required: true, message: `${inpTip + formLabel.pointName}`, trigger: "blur"}],
    supplier: [{required: true, message: `${inpTip + formLabel.supplier}`, trigger: "blur"}],
});
const form = ref({});
const searchParams = ref({
    keywords: '',
});
//查询监控点
const pointList = ref();
const getPoint = async () => {
    await pointApi().search({limit: 100, page: 1}).then((res) => {
        pointList.value = res.data.list
    })
}
getPoint()
//查询供应商
const supplierList = ref();
const getSupplier = async () => {
    await supplierApi().search({limit: 100, page: 1}).then((res) => {
        console.log("供应商" + res.data.list);
        supplierList.value = res.data.list
    })
}
getSupplier()
//查询设备类型
const facilityTypeList = ref();
const getFacilityTypeList = async () => {
    await facilityTypeApi().search({limit: 100, page: 1}).then((res) => {
        facilityTypeList.value = res.data.list
    })
}
getFacilityTypeList()
//获取参数列表数据
//设备参数table
const tableParamData = ref([]);
const getParamList = async() => {
    await commonParameters().search({limit:10000,page: 1}).then((res)=>{
        tableParamData.value = res.data.list;
    })
}
//获取已绑定参数数据
const getSelectParamList = async(val) => {
    await waterFacilityParameter().getParam(val).then((res)=>{
        const data = res.data
        console.log("参数列表",data)
        if(data.length > 0){
            data.forEach( item =>{
                tableParamData.value.forEach((tableItem)=>{
                    if(item.columnsCode == tableItem.mark){
                        tableRef.value.toggleRowSelection(tableItem, undefined)
                    }
                })
            })
        }
    })
}
/** 新增按钮操作 */
async function handleAdd() {
    reset();
    open.value = true;
    isDetail.value = false;
    title.value = "新增";
    console.log('form',form.value)
}

/** 修改按钮操作 */
async function handleUpdate(row) {
    reset();
    // form.value = Object.assign({},row)
    Object.keys(row).forEach(key => {
        if (form.value.hasOwnProperty(key)) {
            form.value[key] = row[key];
        }
    });
    form.value.id = row.id
    open.value = true;
    isDetail.value = true;
    title.value = "修改";
}

/** 删除按钮操作 */
function handleDelete(row) {
    proxy.$modal.confirm('是否确认删除名称为"' + row.contact + '"的数据项?').then(function () {
        return facilityApi().remove(row.id);
    }).then(() => {
        getList();
        proxy.$modal.msgSuccess("删除成功");
    }).catch(() => {
    });
}


/**
 *  新增/修改弹窗Form表单相关
 */
//设备参数弹窗
const tableRef = ref()
const openParamForm = ref(false)
const open = ref(false);
const title = ref("");
const isDetail = ref(false);
const multipleSelection = ref([])
let  tableParamHeader = ref({
    name: '参数名称',
    mark:'参数标识',
    unit: '参数单位',
})
/**
 * 绑定相关
 */
//绑定数据
const facilityData = ref({
    facilityId:'',
    parameterList:[]
})
//已选择设备参数
const handleSelectionParams = (val) =>{
    multipleSelection.value = val
    console.log('esele',val);
}
/**
 * 设备参数操作相关
 */

//提交绑定
const handleSubmit = async() =>{
    multipleSelection.value.forEach((item) =>{
        facilityData.value.parameterList.push({
            columnsCode:item.mark,
            columnsShow:item.name,
            columnsUnits:item.unit,
        })
    })
    let res = await waterFacilityParameter().create(facilityData.value)
    if(res.code == 200){

        proxy.$modal.msgSuccess('绑定成功！')
        facilityData.value.parameterList = []
        openParamForm.value = false
        tableRef.value.clearSelection()

    }else{
        proxy.$modal.msgError('绑定失败！')
        openParamForm.value = false
        tableRef.value.clearSelection()
    }
}
//上传文件，添加图片地址信息
const uploadData = (data) => {
    form.value.facilityUrl = data.toString();
}

/** 提交按钮 */
function submitForm() {
    proxy.$refs["facilityTypeRef"].validate(valid => {
        if (valid) {
            // form.value.contactPhone = Number(form.value.contactPhone)

            if (form.value.id != undefined) {
                facilityApi().modify(form.value).then(res => {
                    proxy.$modal.msgSuccess("修改成功");
                    open.value = false;
                    getList();
                }).catch(() => {
                    open.value = false;
                    proxy.$modal.msgError("修改失败");
                });
            } else {
                facilityApi().create(form.value).then(res => {
                    proxy.$modal.msgSuccess("新增成功");
                    open.value = false;
                    getList();
                }).catch(() => {
                    open.value = false;
                    proxy.$modal.msgError("新增失败");
                });
                ;
            }
        }
    });
}

/** 取消按钮 */
function cancel() {
    open.value = false;
    openParamForm.value = false;
    reset();
}
/** 绑定按钮操作 */
const handleband = async(row) =>{
    facilityData.value.facilityId = row.id
    await getParamList()
    getSelectParamList(row.id)
    openParamForm.value = true
}
/** 表单重置 */
function reset() {
    form.value = {
        facilityCode: '',
        facilityName: '',
        facilityUrl: '',
    };
    proxy.resetForm("facilityTypeRef");
}

getList();
</script>
<template>
    <div class="app-container">
        <el-form :model="searchParams" ref="queryRef" :inline="true">
            <el-form-item label="" prop="">
                <el-input
                        v-model="searchParams.facilityCode"
                        placeholder="请输入搜索信息"
                        clearable
                        style="width: 200px"
                        @keyup.enter="handleQuery"
                />
            </el-form-item>
            <el-form-item>
                <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
                <el-button icon="Refresh" @click="resetQuery">重置</el-button>
            </el-form-item>
        </el-form>

        <el-row :gutter="10" class="mb8">
            <el-col :span="1.5">
                <el-button
                        type="primary"
                        plain
                        icon="Plus"
                        @click="handleAdd"
                >新增
                </el-button>
            </el-col>
        </el-row>
        <!--表格及分页-->
        <el-table  :data="tableData">
            <el-table-column
                    v-for="(item, key, index) of tableHeader"
                    :prop="key.toString()"
                    :label="item"
                    :key="index"
                    align="center"
            >
                <template #default="scope">
                    <div v-if="key.toString() === 'facilityUrl'" style="height: 50px;margin: 0 auto">
                        <img :src="preUrl + scope.row.facilityUrl" class="table-headImg"/>
                    </div>
                </template>
            </el-table-column>
            <el-table-column label="操作" width="180" align="center" class-name="small-padding fixed-width">
                <template #default="scope">
                    <el-button link type="primary" icon="Edit" @click="handleband(scope.row)">参数绑定</el-button>
                    <el-button link type="primary" icon="Edit" v-has="['update',route]"
                               @click="handleUpdate(scope.row)">修改
                    </el-button>
                    <el-button link type="primary" icon="Delete" v-has="['delete',route]"
                               @click="handleDelete(scope.row)">删除
                    </el-button>
                </template>
            </el-table-column>
        </el-table>
        <pagination
                :total="pageParam.total"
                v-model:page="pageParam.page"
                v-model:limit="pageParam.limit"
                :page-sizes="[10,20,30]"
                @pagination="getList"
        />
        <!-- 添加/修改表单 -->
        <el-dialog :title="title" v-model="open" append-to-body center>
            <el-form class="form-box" ref="facilityTypeRef" :model="form" :rules="rules" label-width='120' >
                <el-form-item :label="formLabel.facilityCode" prop="facilityCode">
                    <el-input v-model="form.facilityCode" :placeholder="inpTip+formLabel.facilityCode"/>
                </el-form-item>
                <el-form-item :label="formLabel.facilityName" prop="facilityName">
                    <el-input v-model="form.facilityName" :placeholder="inpTip+formLabel.facilityName"/>
                </el-form-item>
                <el-form-item label="选择设备类型" prop="facilityType">
                    <el-select v-model="form.facilityType" :placeholder="inpTip+formLabel.facilityType">
                        <el-option
                                v-for="(item,index) in facilityTypeList"
                                :label="item.name"
                                :value="item.id"
                                :key="index"
                        ></el-option>
                    </el-select>
                </el-form-item>
                <el-form-item label="选择监控点" prop="pointId">
                    <el-select v-model="form.pointId" :placeholder="inpTip+formLabel.pointId">
                        <el-option
                                v-for="(item,index) in pointList"
                                :label="item.pointName"
                                :value="item.id"
                                :key="index"
                        ></el-option>
                    </el-select>
                </el-form-item>
                <el-form-item label="安装日期" prop="installDate">
                    <el-date-picker
                        v-model="form.installDate"
                        type="date"
                        placeholder="请选择安装日期"
                        format="YYYY-MM-DD"
                        value-format="YYYY-MM-DD"
                        :disabled="isDetail ? true : false"
                    />
                </el-form-item>
                <el-form-item :label="formLabel.remark" prop="remark">
                    <el-input v-model="form.remark" :placeholder="inpTip+formLabel.remark" />
                </el-form-item>
                <el-form-item label="资料上传" prop="facilityUrl">
                    <upload-icons @uploadData="uploadData" :imageList="form.facilityUrl" :limit="1"
                                  :disabled='isDetail ? true : false'></upload-icons>
                    <span style="display: block;">(请上传1张设备图片)</span>
                </el-form-item>
            </el-form>
            <template #footer>
                <div class="dialog-footer">
                    <el-button type="primary" @click="submitForm">确 定</el-button>
                    <el-button @click="cancel">取 消</el-button>
                </div>
            </template>
        </el-dialog>
        <!-- 设备参数弹窗 -->
        <el-dialog title="设备参数" v-model="openParamForm" width="50vw" center align-center append-to-body>
            <!--表格-->
            <el-table ref='tableRef'  :data="tableParamData" height="75vh" @selection-change="handleSelectionParams" >
                <el-table-column type="selection" width="55" align ="center" />
                <el-table-column
                    v-for="(item, key, index) of tableParamHeader"
                    :prop="key.toString()"
                    :label="item"
                    :key="index"
                    align="center"
                ></el-table-column>
            </el-table>
            <template #footer>
                <div class="dialog-footer">
                    <el-button type="primary" @click="handleSubmit">确认绑定</el-button>
                    <el-button @click="cancel">取 消</el-button>
                </div>
            </template>
        </el-dialog>
    </div>
</template>

<style lang="scss" scoped>
.table-headImg{
    max-width: 100px;
    height: 50px;
}
.form-box{
    justify-content: normal;
}
</style>
 